summaryrefslogtreecommitdiffstats
path: root/crypto/http/http_client.c
diff options
context:
space:
mode:
Diffstat (limited to 'crypto/http/http_client.c')
-rw-r--r--crypto/http/http_client.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/crypto/http/http_client.c b/crypto/http/http_client.c
index 64f877abed..a8dda0050a 100644
--- a/crypto/http/http_client.c
+++ b/crypto/http/http_client.c
@@ -814,7 +814,7 @@ static int update_timeout(int timeout, time_t start_time)
* BIO *(*OSSL_HTTP_bio_cb_t) (BIO *bio, void *arg, int conn, int detail);
* The callback may modify the HTTP BIO provided in the bio argument,
* whereby it may make use of any custom defined argument 'arg'.
* During connection establishment, just after BIO_connect_retry(),
* the callback function is invoked with the 'conn' argument being 1
* 'detail' indicating whether a HTTPS (i.e., TLS) connection is requested.
* On disconnect 'conn' is 0 and 'detail' indicates that no error occurred.
@@ -873,7 +873,7 @@ BIO *OSSL_HTTP_transfer(const char *server, const char *port, const char *path,
/* remaining parameters are checked indirectly by the functions called */
(void)ERR_set_mark(); /* prepare removing any spurious libssl errors */
- if (rbio == NULL && BIO_connect_retry(cbio, timeout) <= 0)
+ if (rbio == NULL && BIO_do_connect_retry(cbio, timeout, -1) <= 0)
goto end;
/* now timeout is guaranteed to be >= 0 */
@@ -814,7 +814,7 @@ static int update_timeout(int timeout, time_t start_time)
* The callback may modify the HTTP BIO provided in the bio argument,
* whereby it may make use of any custom defined argument 'arg'.
- * During connection establishment, just after BIO_connect_retry(),
+ * During connection establishment, just after BIO_do_connect_retry(),
* the callback function is invoked with the 'conn' argument being 1
* 'detail' indicating whether a HTTPS (i.e., TLS) connection is requested.